<?php 
/**
 * Plugin Name:       Inventory Import For MyWorks QBO Sync
 * Plugin URI:        http://myworks.design/software/woocommerce-quickbooks-online-automatic-sync/
 * Description:       Update QuickBooks Online Inventory (Stock) Into WooCommerce Every 10 Minutes.
 * Version:           1.0.0
 * Author:            MyWorks Design
 * Author URI:        http://myworks.design/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       mw_wc_qbo_sync_inventory_import
 * Domain Path:       /languages
 */
 
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

function mwqbosync_inventory_import_plugin_avtivation(){

  $active_plugins = get_option('active_plugins');
  if(in_array('myworks-wc-qbo-sync/myworks-wc-qbo-sync.php',$active_plugins)){
  	return true;
  }else{
  	$error_message = __('This plugin requires <a target="_blank" href="http://myworks.design/software/woocommerce-quickbooks-online-automatic-sync/">MyWorks Woo Sync for QuickBooks Online</a> plugin to be active!', 'mw_wc_qbo_sync');
	die($error_message);
  }
}

register_activation_hook(__FILE__, 'mwqbosync_inventory_import_plugin_avtivation');

function mwqbosync_inventory_import_plugin_deactivation(){
	wp_clear_scheduled_hook('mwqbosync_inventory_import_schedule_hook');
	return true;
}

register_deactivation_hook( __FILE__, 'mwqbosync_inventory_import_plugin_deactivation' );

add_action('init', 'mwqbosync_inventory_import_schedule_cron',10);

function mwqbosync_inventory_import_schedule_cron(){
	if (class_exists('MyWorks_WC_QBO_Sync_QBO_Lib')) {
		if(!wp_next_scheduled('mwqbosync_inventory_import_schedule_hook')){
			wp_schedule_event(time(), '10min', 'mwqbosync_inventory_import_schedule_hook');
		}		
		add_action('mwqbosync_inventory_import_schedule_hook', 'mwqbosync_inventory_import_schedule_hook_callback');
	}
}

function mwqbosync_inventory_import_cron_schedules($schedules){
    if(!isset($schedules["10min"])){
        $schedules["10min"] = array(
            'interval' => 10*60,
            'display' => __('Once every 10 minutes'));
    }   
    return $schedules;
}
add_filter('cron_schedules','mwqbosync_inventory_import_cron_schedules');

function mwqbosync_inventory_import_schedule_hook_callback(){
	if (class_exists('MyWorks_WC_QBO_Sync_QBO_Lib')) {
		global $MSQS_QL;
		
		if($MSQS_QL->is_connected()){
			$Context = $MSQS_QL->getContext();
			$realm = $MSQS_QL->getRealm();
			
			$interval_mins = 10;
			$now = new DateTime(null, new DateTimeZone('America/Los_Angeles'));
			$datetime = $now->format('Y-m-d H:i:s');
			$datetime = date('Y-m-d H:i:s',strtotime("-{$interval_mins} minutes",strtotime($datetime)));
			$timestamp = date('Y-m-d', strtotime($datetime)) . 'T' . date('H:i:s', strtotime($datetime));
			
			$cdc_objects = array('Item');
			
			$CDCService = new QuickBooks_IPP_Service_ChangeDataCapture();
			$cdc = $CDCService->cdc($Context, $realm, $cdc_objects,	$timestamp);
			
			if($cdc && count($cdc)){
				foreach ($cdc as $object_type => $list){
					if($list && count($list)){
						foreach ($list as $Object){
							if($object_type=='Item'){
								$item_id = (int) $MSQS_QL->qbo_clear_braces($Object->getId());
								$item_type = $Object->getType();
								if($item_id && $item_type=='Inventory'){
									$return_id = $MSQS_QL->UpdateWooCommerceInventory(array('qbo_inventory_id'=>$item_id,'cron'=>true));
								}
							}
						}
					}										
				}
			}
		}		
	}	
}
?>